pub enum UseArrowFunction {}
Use arrow functions over function expressions.

An arrow function expression is a compact alternative to a regular function expression, with an important distinction: this is not bound to the arrow function. It inherits this from its parent scope.

This rule proposes turning all function expressions that are not generators (function*) and don’t use this into arrow functions.

Examples

Invalid

const z = function() {
    return 0;
}
const delegatedFetch = async function(url) {
    return await fetch(url);
}

Valid

const f = function() {
    return this.prop;
}

Named function expressions are ignored:

const z = function z() {
    return 0;
}

Function expressions that declare the type of this are also ignored:

const z = function(this: A): number {
    return 0;
}